# Pyanist

Pyanist is a tool that allows chorded typing using a regular N-key rollover keyboard.
It allows you to use chorded typing in addition to normal typing, which means that you can
get started by chording a few frequent words instead of having to learn a whole system 
from scratch.


## Running Pyanist

After you've installed Pyanist, you can run in using the command:

```bash
pyanist
```


# Attributions/sources

./word-freq-top5000.csv - https://raw.githubusercontent.com/filiph/english_words/master/data/word-freq-top5000.csv (MIT)



